==> tomee-project-8.0.3-source-release.zip: tomee-project-8.0.3/itests/openejb-itests-beans/src/main/java/org/apache/openejb/test/entity/bmp/BasicBmpHome.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.openejb.test.entity.bmp;

import java.util.Enumeration;


public interface BasicBmpHome extends javax.ejb.EJBHome {

    public BasicBmpObject createObject(String name)
        throws javax.ejb.CreateException, java.rmi.RemoteException;

    public BasicBmpObject findByPrimaryKey(Integer primarykey)
        throws javax.ejb.FinderException, java.rmi.RemoteException;

    public java.util.Collection findEmptyCollection()
        throws javax.ejb.FinderException, java.rmi.RemoteException;

    public java.util.Collection findByLastName(String lastName)
        throws javax.ejb.FinderException, java.rmi.RemoteException;

    public Enumeration findEmptyEnumeration()
        throws javax.ejb.FinderException, java.rmi.RemoteException;

    public int sum(int x, int y) throws java.rmi.RemoteException;
}

==> tomee-project-10.1.2-source-release.zip: tomee-project-10.1.2/itests/openejb-itests-beans/src/main/java/org/apache/openejb/test/entity/bmp/BasicBmpHome.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.openejb.test.entity.bmp;

import java.util.Enumeration;


public interface BasicBmpHome extends jakarta.ejb.EJBHome {

    public BasicBmpObject createObject(String name)
        throws jakarta.ejb.CreateException, java.rmi.RemoteException;

    public BasicBmpObject findByPrimaryKey(Integer primarykey)
        throws jakarta.ejb.FinderException, java.rmi.RemoteException;

    public java.util.Collection findEmptyCollection()
        throws jakarta.ejb.FinderException, java.rmi.RemoteException;

    public java.util.Collection findByLastName(String lastName)
        throws jakarta.ejb.FinderException, java.rmi.RemoteException;

    public Enumeration findEmptyEnumeration()
        throws jakarta.ejb.FinderException, java.rmi.RemoteException;

    public int sum(int x, int y) throws java.rmi.RemoteException;
}
